@@ -67,7 +67,7 @@ get_font_style_from_selection (HTMLEngine *engine)
 		if (html_object_is_text (p.object) && p.offset != html_object_get_length (p.object)) {
 			gint index = 0;
 			if (first) {
-				gint index = g_utf8_offset_to_pointer (HTML_TEXT (p.object)->text, offset) - HTML_TEXT (p.object)->text;
+				index = g_utf8_offset_to_pointer (HTML_TEXT (p.object)->text, offset) - HTML_TEXT (p.object)->text;
 				style = html_text_get_fontstyle_at_index (HTML_TEXT (p.object), index);
 				first = FALSE;
 			}
@@ -125,9 +125,14 @@ get_color_from_selection (HTMLEngine *engine)
 GtkHTMLFontStyle
 html_engine_get_document_font_style (HTMLEngine *engine)
 {
-	g_return_val_if_fail (engine != NULL, GTK_HTML_FONT_STYLE_DEFAULT);
-	g_return_val_if_fail (HTML_IS_ENGINE (engine), GTK_HTML_FONT_STYLE_DEFAULT);
-	g_return_val_if_fail (engine->editable, GTK_HTML_FONT_STYLE_DEFAULT);
+	if (!engine)
+		return GTK_HTML_FONT_STYLE_DEFAULT;
+
+	if (!HTML_IS_ENGINE (engine))
+		return GTK_HTML_FONT_STYLE_DEFAULT;
+
+	if (!engine->editable)
+		return GTK_HTML_FONT_STYLE_DEFAULT;
 
 	if (html_engine_is_selection_active (engine))
 		return get_font_style_from_selection (engine);
@@ -168,7 +173,7 @@ html_engine_get_document_color (HTMLEngine *engine)
 			return NULL;
 		else {
 			HTMLObject *obj;
-			gint offset, index;
+			gint offset;
 
 			obj = html_engine_text_style_object (engine, &offset);
 			return obj
@@ -324,9 +329,14 @@ html_engine_set_font_style (HTMLEngine *e,
 	gboolean rv;
 	GtkHTMLFontStyle old = e->insertion_font_style;
 
-	g_return_val_if_fail (e != NULL, FALSE);
-	g_return_val_if_fail (HTML_IS_ENGINE (e), FALSE);
-	g_return_val_if_fail (e->editable, FALSE);
+	if (!e)
+		return FALSE;
+
+	if (!HTML_IS_ENGINE (e))
+		return FALSE;
+
+	if (!e->editable)
+		return FALSE;
 
 	/* printf ("and %d or %d\n", and_mask, or_mask); */
 	e->insertion_font_style &= and_mask;
